<?php

/**
 * @file
 * Configuration form for Lazy-load.
 */

/**
 * Lazy-load configuration form.
 */
function lazy_configuration_form($form, $form_state) {
  $defaults = variable_get('lazy_filter_defaults');

  $form['info'] = array(
    '#type' => 'item',
    '#title' => t('Global settings'),
    '#description' => t('The configuration options available on this form applies to all <a href="!path">text-formats</a> that have %filter filter enabled.', array(
      '!path' => url('admin/config/content/formats'),
      '%filter' => 'Lazy-load',
    )),
  );

  $form['lazy_filter_alter_tag'] = array(
    '#type' => 'select',
    '#title' => t('Apply to'),
    '#options' => array(
      'img iframe' => t('Images & Iframes'),
      'img' => t('Images only'),
      'iframe' => t('IFrames only'),
    ),
    '#default_value' => variable_get('lazy_filter_alter_tag', $defaults['lazy_filter_alter_tag']),
    '#description' => t('Select the elements to be lazy-loaded.'),
  );

  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['advanced']['lazy_filter_loadInvisible'] = array(
    '#type' => 'checkbox',
    '#title' => t('loadInvisible'),
    '#description' => t('If checked loads invisible (hidden) elements. Default is %val', array('%val' => ($defaults['lazy_filter_loadInvisible']) ? 'checked' : 'unchecked')),
    '#default_value' => variable_get('lazy_filter_loadInvisible', $defaults['lazy_filter_loadInvisible']),
    '#return_value' => TRUE,
  );

  $form['advanced']['lazy_filter_offset'] = array(
    '#type' => module_exists('elements') ? 'numberfield' : 'textfield',
    '#title' => t('offset'),
    '#description' => t('The offset controls how early you want the elements to be loaded before they’re visible. Default is %val, so %val pixel before an element is visible it’ll start loading.', array('%val' => $defaults['lazy_filter_offset'])),
    '#default_value' => variable_get('lazy_filter_offset', $defaults['lazy_filter_offset']),
  );

  $form['advanced']['lazy_filter_saveViewportOffsetDelay'] = array(
    '#type' => module_exists('elements') ? 'numberfield' : 'textfield',
    '#title' => t('saveViewportOffsetDelay'),
    '#description' => t('Delay for how often it should call the saveViewportOffset function on resize. Default is %val', array('%val' => $defaults['lazy_filter_saveViewportOffsetDelay'])),
    '#default_value' => variable_get('lazy_filter_saveViewportOffsetDelay', $defaults['lazy_filter_saveViewportOffsetDelay']),
  );

  $form['advanced']['lazy_filter_validateDelay'] = array(
    '#type' => module_exists('elements') ? 'numberfield' : 'textfield',
    '#title' => t('validateDelay'),
    '#description' => t('Delay for how often it should call the validate function on scroll/resize. Default is %val', array('%val' => $defaults['lazy_filter_validateDelay'])),
    '#default_value' => variable_get('lazy_filter_validateDelay', $defaults['lazy_filter_validateDelay']),
  );

  $form['advanced']['lazy_filter_selector'] = array(
    '#type' => 'textfield',
    '#title' => t('Selector class'),
    '#description' => t('Element selector for elements that should lazy load. Do not include a leading period. Default is %val', array('%val' => $defaults['lazy_filter_selector'])),
    '#default_value' => variable_get('lazy_filter_selector', $defaults['lazy_filter_selector']),
  );

  $form['advanced']['lazy_filter_skipClass'] = array(
    '#type' => 'textfield',
    '#title' => t('skipClass'),
    '#description' => t('Elements having this class name will be ignored. Default is %val', array('%val' => $defaults['lazy_filter_skipClass'])),
    '#default_value' => variable_get('lazy_filter_skipClass', $defaults['lazy_filter_skipClass']),
  );

  $form['advanced']['lazy_filter_errorClass'] = array(
    '#type' => 'textfield',
    '#title' => t('errorClass'),
    '#description' => t('The classname an element will get if something goes wrong. Default is %val', array('%val' => $defaults['lazy_filter_errorClass'])),
    '#default_value' => variable_get('lazy_filter_errorClass', $defaults['lazy_filter_errorClass']),
  );

  $form['advanced']['lazy_filter_successClass'] = array(
    '#type' => 'textfield',
    '#title' => t('successClass'),
    '#description' => t('The classname an element will get when loaded. Default is %val', array('%val' => $defaults['lazy_filter_successClass'])),
    '#default_value' => variable_get('lazy_filter_successClass', $defaults['lazy_filter_successClass']),
  );

  $form['advanced']['lazy_filter_src'] = array(
    '#type' => 'textfield',
    '#title' => t('src'),
    '#description' => t('Attribute where the original element source will be assigned. Do not change this unless attribute is used for other purposes. Default is %val', array('%val' => $defaults['lazy_filter_src'])),
    '#default_value' => variable_get('lazy_filter_src', $defaults['lazy_filter_src']),
  );

  $form['advanced']['lazy_filter_placeholderSrc'] = array(
    '#type' => 'textfield',
    '#title' => t('Placeholder image URL'),
    '#description' => t('Default is %val', array('%val' => $defaults['lazy_filter_placeholderSrc'])),
    '#default_value' => variable_get('lazy_filter_placeholderSrc', $defaults['lazy_filter_placeholderSrc']),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  return $form;
}

/**
 * Submit handler for lazy_configuration_form().
 */
function lazy_configuration_form_submit($form, &$form_state) {
  $int_value = array(
    'lazy_filter_offset',
    'lazy_filter_saveViewportOffsetDelay',
    'lazy_filter_validateDelay',
  );
  $bool_value = array(
    'lazy_filter_loadInvisible',
  );

  // Exclude unnecessary elements.
  form_state_values_clean($form_state);
  foreach ($form_state['values'] as $key => $value) {
    if (in_array($key, $int_value)) {
      $value = intval($value);
    }
    if (in_array($key, $bool_value)) {
      $value = boolval($value);
    }
    variable_set($key, $value);
  }
  drupal_set_message(t('The configuration options have been saved.'));
}
